@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Ark::Plugin;
 
-sub prepare_encoding { };
+sub prepare_encoding { }; # XXX: Plack::Request::WithEncoding should support no encoding option.
 sub finalize_encoding { };
 
 1;
